@@ -31,7 +31,7 @@ public:
   App_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
   virtual ~App_Glom();
 
-  virtual void init(); //override
+  virtual void init(const Glib::ustring& document_uri = Glib::ustring()); //override
 
   virtual void statusbar_set_text(const Glib::ustring& strText);
   virtual void statusbar_clear();
@@ -50,11 +50,16 @@ public:
 protected:
   virtual void init_layout(); //override.
   virtual void init_menus(); //override.
+  virtual void init_menus_help(); //override
   virtual void init_create_document(); //override
   virtual void on_document_load(); //override.
 
   virtual void offer_new_or_existing();
 
+  virtual void on_menu_help_contents();
+  virtual void on_menu_userlevel_developer();
+  virtual void on_menu_userlevel_operator();
+
   virtual void on_userlevel_changed(AppState::userlevels userlevel);
 
   virtual Bakery::App* new_instance(); //Override
