@@ -126,7 +126,8 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade:
   add_view(m_pDialog_Fields); //Also a composite view.
   add_view(m_pDialog_Relationships); //Also a composite view.
   add_view(&m_Notebook_Data); //Also a composite view.
-
+  add_view(&m_Notebook_Find); //Also a composite view.
+  
   on_userlevel_changed(AppState::USERLEVEL_OPERATOR); //A default to show before a document is created or loaded.
   show_all();
 }
@@ -274,9 +275,9 @@ void Frame_Glom::show_table(const Glib::ustring& strTableName)
   show_all();
 }
 
-void Frame_Glom::on_menu_userlevel_Developer(Glib::RefPtr<Gtk::RadioAction> action)
+void Frame_Glom::on_menu_userlevel_Developer(const Glib::RefPtr<Gtk::RadioAction>& action)
 {
-  if(action->get_active())
+  if(action && action->get_active())
   {
     Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
     if(document)
@@ -288,9 +289,9 @@ void Frame_Glom::on_menu_userlevel_Developer(Glib::RefPtr<Gtk::RadioAction> acti
   }
 }
 
-void Frame_Glom::on_menu_userlevel_Operator(Glib::RefPtr<Gtk::RadioAction> action)
+void Frame_Glom::on_menu_userlevel_Operator(const Glib::RefPtr<Gtk::RadioAction>& action)
 {
-  if(action->get_active())
+  if(action &&  action->get_active())
   {
     Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
     if(document)
@@ -621,5 +622,10 @@ void Frame_Glom::on_developer_dialog_hide()
   show_table(m_strTableName);
 }
 
+void Frame_Glom::on_menu_developer_recreate_structure()
+{
+}
+ 
+
 
 
