@@ -66,10 +66,10 @@ void Box_DB_Table_Definition::init()
   m_colPrimaryKey = m_AddDel.add_column("Primary Key", AddDelColumnInfo::STYLE_Boolean);
 
   //Connect signals:
-  m_AddDel.signal_user_added().connect(sigc::mem_fun(*this, &Box_DB_Table_Definition::on_AddDel_add));
-  m_AddDel.signal_user_requested_delete().connect(sigc::mem_fun(*this, &Box_DB_Table_Definition::on_AddDel_delete));
-  m_AddDel.signal_user_changed().connect(sigc::mem_fun(*this, &Box_DB_Table_Definition::on_AddDel_changed));
-  m_AddDel.signal_user_requested_edit().connect(sigc::mem_fun(*this, &Box_DB_Table_Definition::on_AddDel_edit));
+  m_AddDel.signal_user_added().connect(sigc::mem_fun(*this, &Box_DB_Table_Definition::on_adddel_add));
+  m_AddDel.signal_user_requested_delete().connect(sigc::mem_fun(*this, &Box_DB_Table_Definition::on_adddel_delete));
+  m_AddDel.signal_user_changed().connect(sigc::mem_fun(*this, &Box_DB_Table_Definition::on_adddel_changed));
+  m_AddDel.signal_user_requested_edit().connect(sigc::mem_fun(*this, &Box_DB_Table_Definition::on_adddel_edit));
 
   //React to changes in the field properties:
   m_pDialog->signal_apply().connect(sigc::mem_fun(*this, &Box_DB_Table_Definition::on_Properties_apply));
@@ -134,7 +134,7 @@ void Box_DB_Table_Definition::fill_from_database()
   fill_end();
 }
 
-void Box_DB_Table_Definition::on_AddDel_add(const Gtk::TreeModel::iterator& row)
+void Box_DB_Table_Definition::on_adddel_add(const Gtk::TreeModel::iterator& row)
 {
   Glib::ustring strName = m_AddDel.get_value(row, m_colName);
   if(!strName.empty())
@@ -151,6 +151,7 @@ void Box_DB_Table_Definition::on_AddDel_add(const Gtk::TreeModel::iterator& row)
       //This must match the SQL statement above:
       Field field;
       field.set_name(strName);
+      field.set_title( util_title_from_string(strName) ); //Start with a title that might be useful.
       field.set_glom_type(Field::TYPE_NUMERIC);
 
       Gnome::Gda::FieldAttributes field_info = field.get_field_info();
@@ -164,7 +165,7 @@ void Box_DB_Table_Definition::on_AddDel_add(const Gtk::TreeModel::iterator& row)
   }
 }
 
-void Box_DB_Table_Definition::on_AddDel_delete(const Gtk::TreeModel::iterator& rowStart, const Gtk::TreeModel::iterator&  rowEnd)
+void Box_DB_Table_Definition::on_adddel_delete(const Gtk::TreeModel::iterator& rowStart, const Gtk::TreeModel::iterator&  rowEnd)
 {
   Gtk::TreeModel::iterator iterAfterEnd = rowEnd;
   if(iterAfterEnd != m_AddDel.get_model()->children().end())
@@ -183,7 +184,7 @@ void Box_DB_Table_Definition::on_AddDel_delete(const Gtk::TreeModel::iterator& r
   fill_from_database();
 }
 
-void Box_DB_Table_Definition::on_AddDel_changed(const Gtk::TreeModel::iterator& row, guint /* col */)
+void Box_DB_Table_Definition::on_adddel_changed(const Gtk::TreeModel::iterator& row, guint /* col */)
 {
   //Get old field definition:
   Document_Glom* pDoc = static_cast<Document_Glom*>(get_document());
@@ -221,7 +222,7 @@ void Box_DB_Table_Definition::on_AddDel_changed(const Gtk::TreeModel::iterator&
   }
 }
 
-void Box_DB_Table_Definition::on_AddDel_edit(const Gtk::TreeModel::iterator& row)
+void Box_DB_Table_Definition::on_adddel_edit(const Gtk::TreeModel::iterator& row)
 {
   m_Field_BeingEdited = get_field_definition(row);
   
@@ -387,7 +388,9 @@ void Box_DB_Table_Definition::change_definition(const Field& fieldOld, Field fie
 
     //Update field names where they are used in relationships.
     if(field_name_old != field.get_name())
+    {
       pDoc->change_field_name(m_strTableName, field_name_old, field.get_name());
+    }
   }
 
 
